from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .GroupFilter_CountMatchFilter import GroupFilter_CountMatchFilter
from .Util import Util
from .History import History
from .OptionsField import OptionsField
from .TextOverlay import TextOverlay
from .CharCompareFilter import CharCompareFilter
from .LongField import LongField
from .CommandManager import CommandManager
from .IRecipeBookResults import IRecipeBookResults
from .Button import Button
from .IDraw2D import IDraw2D
from .TextInput import TextInput
from .Prism_typescript import Prism_typescript
from .DoubleField import DoubleField
from .BaseScriptContext_ScriptAssertionError import BaseScriptContext_ScriptAssertionError
from .IChunkSection import IChunkSection
from .ClientConfigV2 import ClientConfigV2
from .IItemCooldownManager import IItemCooldownManager
from .Prism_groovy import Prism_groovy
from .ColorMapSetting import ColorMapSetting
from .IPalettedContainer import IPalettedContainer
from .ColorMapSetting_ColorEntry import ColorMapSetting_ColorEntry
from .PlayerInput import PlayerInput
from .IFontManager import IFontManager
from .IBeaconScreen import IBeaconScreen
from .IRecipeBookWidget import IRecipeBookWidget
from .StringifyFilter import StringifyFilter
from .IHorseScreen import IHorseScreen
from .WrappedClassInstance_MethodSigParts import WrappedClassInstance_MethodSigParts
from .IFilter import IFilter
from .IPackedIntegerArray import IPackedIntegerArray
from .RenderCommon_Item import RenderCommon_Item
from .ChatHistoryManager import ChatHistoryManager
from .Inventory import Inventory
from .Sorting_SortByTriggerName import Sorting_SortByTriggerName
from .BaseWrappedException_HostLocation import BaseWrappedException_HostLocation
from .TranslationUtil import TranslationUtil
from .IntField import IntField
from .BaseListener import BaseListener
from .AbstractSettingContainer import AbstractSettingContainer
from .SelectorDropdownOverlay import SelectorDropdownOverlay
from .ServiceContainer import ServiceContainer
from .FileChooser_fileObj import FileChooser_fileObj
from .BlockStateFilter import BlockStateFilter
from .EnchantInventory import EnchantInventory
from .IMerchantScreen import IMerchantScreen
from .KeyMacrosScreen import KeyMacrosScreen
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder
from .History_TabLinesKeepCursor import History_TabLinesKeepCursor
from .History_HistoryStep import History_HistoryStep
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .Scrollbar import Scrollbar
from .BooleanCompareFilter import BooleanCompareFilter
from .FileChooser_sortFile import FileChooser_sortFile
from .History_Add import History_Add
from .EventRegistry import EventRegistry
from .Websocket import Websocket
from .ScriptTrigger import ScriptTrigger
from .ServiceListTopbar import ServiceListTopbar
from .Event import Event
from .KeyListener import KeyListener
from .BasicFilter import BasicFilter
from .ExtensionLoader import ExtensionLoader
from .VillagerInventory import VillagerInventory
from .BaseWrappedException import BaseWrappedException
from .PerExecLanguageLibrary import PerExecLanguageLibrary
from .NumberCompareFilter import NumberCompareFilter
from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
from .ClassBuilder import ClassBuilder
from .CustomClickEvent import CustomClickEvent
from .TextBuilder import TextBuilder
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .IContainerParent import IContainerParent
from .PositionCommon_Pos2D import PositionCommon_Pos2D
from .StringMapSetting_StringEntry import StringMapSetting_StringEntry
from .BaseWrappedException_GuestLocation import BaseWrappedException_GuestLocation
from .FileChooser import FileChooser
from .Sorting_SortByEnabled import Sorting_SortByEnabled
from .PrimitiveSettingGroup import PrimitiveSettingGroup
from .LibraryBuilder import LibraryBuilder
from .Draw3D import Draw3D
from .Prism_kotlin import Prism_kotlin
from .FReflection_CombinedVariableClassLoader import FReflection_CombinedVariableClassLoader
from .IClientPlayerEntity import IClientPlayerEntity
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .TickSync import TickSync
from .EventChooser_EventObj import EventChooser_EventObj
from .StringField import StringField
from .BaseScriptContext_SleepRunnable import BaseScriptContext_SleepRunnable
from .AutoCompleteSuggestor import AutoCompleteSuggestor
from .MovementDummy import MovementDummy
from .IOverlayParent import IOverlayParent
from .RenderCommon_Text import RenderCommon_Text
from .ScriptScreen import ScriptScreen
from .IMinecraftClient import IMinecraftClient
from .WorldScannerBuilder import WorldScannerBuilder
from .Draw2D import Draw2D
from .FloatField import FloatField
from .PositionCommon import PositionCommon
from .StringMapSetting import StringMapSetting
from .FJsMacros_EventAndContext import FJsMacros_EventAndContext
from .Sorting_MacroSortMethod import Sorting_MacroSortMethod
from .CancelScreen_RTCSort import CancelScreen_RTCSort
from .AboutOverlay import AboutOverlay
from .NoStyleCodeCompiler import NoStyleCodeCompiler
from .CheckBoxContainer import CheckBoxContainer
from .ListContainer import ListContainer
from .DocletReplaceParams import DocletReplaceParams
from .PerLanguageLibrary import PerLanguageLibrary
from .Extension_ExtMatch import Extension_ExtMatch
from .BaseScriptContext import BaseScriptContext
from .Pair import Pair
from .ProxyBuilder import ProxyBuilder
from .IInventory import IInventory
from .IScreen import IScreen
from .TextPrompt import TextPrompt
from .Prism_json import Prism_json
from .ServiceScreen import ServiceScreen
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder
from .Extension import Extension
from .ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder import ClassBuilder_AnnotationBuilder_AnnotationArrayBuilder
from .Mappings import Mappings
from .BaseLibrary import BaseLibrary
from .ICategoryTreeParent import ICategoryTreeParent
from .ServiceTrigger import ServiceTrigger
from .WrappedScript import WrappedScript
from .StringCompareFilter_FilterMethod import StringCompareFilter_FilterMethod
from .CommandNodeAccessor import CommandNodeAccessor
from .PrioryFiFoTaskQueue import PrioryFiFoTaskQueue
from .Draw3D_Box import Draw3D_Box
from .ClassWrapperFilter import ClassWrapperFilter
from .RenderCommon_Rect import RenderCommon_Rect
from .IMerchantEntity import IMerchantEntity
from .WorldScanner import WorldScanner
from .DefaultCodeCompiler import DefaultCodeCompiler
from .BlockFilter import BlockFilter
from .Draw3D_Surface import Draw3D_Surface
from .HTTPRequest import HTTPRequest
from .ISignEditScreen import ISignEditScreen
from .FileField import FileField
from .OrFilter import OrFilter
from .FKeyBind_KeyTracker import FKeyBind_KeyTracker
from .RenderCommon import RenderCommon
from .IAdvancedFilter import IAdvancedFilter
from .LibraryRegistry import LibraryRegistry
from .TickBasedEvents import TickBasedEvents
from .ILoomScreen import ILoomScreen
from .NotFilter import NotFilter
from .SettingsOverlay import SettingsOverlay
from .HTTPRequest_Response import HTTPRequest_Response
from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
from .Prism_python import Prism_python
from .MacroScreen import MacroScreen
from .ExtensionClassLoader import ExtensionClassLoader
from .ConfigFolder import ConfigFolder
from .ICompare import ICompare
from .IBossBarHud import IBossBarHud
from .History_TabLines import History_TabLines
from .Mappings_MethodData import Mappings_MethodData
from .Profile import Profile
from .BaseEventRegistry import BaseEventRegistry
from .GroupFilter_NoneMatchFilter import GroupFilter_NoneMatchFilter
from .MacroListTopbar import MacroListTopbar
from .RenderCommon_Image import RenderCommon_Image
from .BooleanField import BooleanField
from .Prism_regex import Prism_regex
from .IPlayerListHud import IPlayerListHud
from .Prism_lua import Prism_lua
from .ClassBuilder_FieldBuilder_FieldInitializerBuilder import ClassBuilder_FieldBuilder_FieldInitializerBuilder
from .EventListener import EventListener
from .BaseProfile import BaseProfile
from .TPSData import TPSData
from .ConfirmOverlay import ConfirmOverlay
from .SynchronizedWeakHashSet import SynchronizedWeakHashSet
from .GroupFilter import GroupFilter
from .Neighbor import Neighbor
from .Draw3D_Line import Draw3D_Line
from .StringHashTrie import StringHashTrie
from .ConfigManager import ConfigManager
from .EventLockWatchdog import EventLockWatchdog
from .AndFilter import AndFilter
from .OverlayContainer import OverlayContainer
from .PositionCommon_Plane3D import PositionCommon_Plane3D
from .AbstractMapSettingContainer import AbstractMapSettingContainer
from .Mappings_ClassData import Mappings_ClassData
from .BaseLanguage import BaseLanguage
from .CategoryTreeContainer import CategoryTreeContainer
from .MultiElementContainer import MultiElementContainer
from .BeaconInventory import BeaconInventory
from .AutoCompleteSuggestion import AutoCompleteSuggestion
from .AnnotatedCheckBox import AnnotatedCheckBox
from .MacroContainer import MacroContainer
from .PositionCommon_Vec2D import PositionCommon_Vec2D
from .ProxyBuilder_ProxyReference import ProxyBuilder_ProxyReference
from .IChatHud import IChatHud
from .History_Replace import History_Replace
from .GroupFilter_AllMatchFilter import GroupFilter_AllMatchFilter
from .XorFilter import XorFilter
from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
from .StringCompareFilter import StringCompareFilter
from .EditorScreen import EditorScreen
from .Sorting_SortByFileName import Sorting_SortByFileName
from .BaseScreen import BaseScreen
from .IItemCooldownEntry import IItemCooldownEntry
from .Prism_ruby import Prism_ruby
from .JsMacros import JsMacros
from .EventMacrosScreen import EventMacrosScreen
from .Core import Core
from .CoreConfigV2 import CoreConfigV2
from .SelectCursor import SelectCursor
from .History_Remove import History_Remove
from .PositionCommon_Vec3D import PositionCommon_Vec3D
from .Websocket_Disconnected import Websocket_Disconnected
from .Prism_javascript import Prism_javascript
from .AbstractSettingField import AbstractSettingField
from .DocletReplaceReturn import DocletReplaceReturn
from .Option import Option
from .MethodWrapper import MethodWrapper
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .Library import Library
from .Prism import Prism
from .ProfileSetting import ProfileSetting
from .FileMapSetting import FileMapSetting
from .FileMapSetting_FileEntry import FileMapSetting_FileEntry
from .WrappedClassInstance import WrappedClassInstance
from .Mappings_MappedClass import Mappings_MappedClass
from .FJsMacros_ScriptEventListener import FJsMacros_ScriptEventListener
from .LoomInventory import LoomInventory
from .ServiceManager_ServiceStatus import ServiceManager_ServiceStatus
from .CancelScreen import CancelScreen
from .GroupFilter_AnyMatchFilter import GroupFilter_AnyMatchFilter
from .PerExecLibrary import PerExecLibrary
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler
from .ServiceManager import ServiceManager
from .MovementQueue import MovementQueue
from .EventChooser import EventChooser
from .OptionType import OptionType
from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .TextStyleCompiler import TextStyleCompiler
from .Sorting import Sorting
from .FileHandler import FileHandler
from .ProfileSetting_ProfileEntry import ProfileSetting_ProfileEntry
from .IEventListener import IEventListener
from .Prism_clike import Prism_clike
from .IPalettedContainerData import IPalettedContainerData
from .ClassBuilder_BodyBuilder import ClassBuilder_BodyBuilder
from .History_ShiftLine import History_ShiftLine
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder
from .BossBarConsumer import BossBarConsumer
from .ScriptCodeCompiler import ScriptCodeCompiler
from .CommandBuilder import CommandBuilder
from .RunningContextContainer import RunningContextContainer

File = TypeVar["java.io.File"]




from typing import overload
from typing import TypeVar

File = TypeVar["java.io.File"]
Comparator = TypeVar["java.util.Comparator_java.io.File_"]

class FileChooser_sortFile(Comparator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, a: File, b: File) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .PerExecLibrary import PerExecLibrary
from .TickSync import TickSync
from .BaseScriptContext import BaseScriptContext
from .MethodWrapper import MethodWrapper
from .OptionsHelper import OptionsHelper
from .ServerInfoHelper import ServerInfoHelper

MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]

class FClient(PerExecLibrary):
	"""Functions that interact with minecraft that don't fit into their own module.

An instance of this class is passed to scripts as the 'Client' variable.\n
	Since: 1.2.9 
	"""
	tickSynchronizer: TickSync

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def getMinecraft(self) -> MinecraftClient:
		"""
		Since: 1.0.0 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			the raw minecraft client class, it may be useful to use Minecraft Mappings Viewer for this. 
		"""
		pass

	@overload
	def runOnMainThread(self, runnable: MethodWrapper) -> None:
		"""Run your task on the main minecraft thread\n
		Since: 1.4.0 

		Args:
			runnable: task to run 
		"""
		pass

	@overload
	def runOnMainThread(self, runnable: MethodWrapper, watchdogMaxTime: float) -> None:
		"""
		Since: 1.6.5 

		Args:
			runnable: 
			watchdogMaxTime: max time for the watchdog to wait before killing the script 
		"""
		pass

	@overload
	def getGameOptions(self) -> OptionsHelper:
		"""
		Since: 1.1.7 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			an OptionsHelper for the game options. 
		"""
		pass

	@overload
	def mcVersion(self) -> str:
		"""
		Since: 1.1.2 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			the current minecraft version as a String . 
		"""
		pass

	@overload
	def getFPS(self) -> str:
		"""
		Since: 1.2.0 (was in the 'jsmacros' library until 1.2.9) 

		Returns:
			the fps debug string from minecraft. 
		"""
		pass

	@overload
	def loadWorld(self, folderName: str) -> None:
		"""Join singleplayer world\n
		Since: 1.6.6 

		Args:
			folderName: 
		"""
		pass

	@overload
	def connect(self, ip: str) -> None:
		"""
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 

		Args:
			ip: 
		"""
		pass

	@overload
	def connect(self, ip: str, port: int) -> None:
		"""Connect to a server\n
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 

		Args:
			port: 
			ip: 
		"""
		pass

	@overload
	def disconnect(self) -> None:
		"""
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 
		"""
		pass

	@overload
	def disconnect(self, callback: MethodWrapper) -> None:
		"""Disconnect from a server with callback.\n
		Since: 1.2.3 (was in the 'jsmacros' library until 1.2.9) 'callback' defaults to 'null' 

		Args:
			callback: calls your method as a Consumer Boolean 
		"""
		pass

	@overload
	def shutdown(self) -> None:
		"""Closes the client (stops the game).
Waits until the game has stopped, meaning no further code is executed (for obvious reasons).
Warning: this does not wait on joined threads, so your script may stop at an undefined point.\n
		Since: 1.6.0 
		"""
		pass

	@overload
	def waitTick(self) -> None:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def waitTick(self, i: int) -> None:
		"""waits the specified number of client ticks.
don't use this on an event that the main thread waits on (joins)... that'll cause circular waiting.\n
		Since: 1.2.6 

		Args:
			i: 
		"""
		pass

	@overload
	def ping(self, ip: str) -> ServerInfoHelper:
		"""
		Since: 1.6.5 

		Args:
			ip: 
		"""
		pass

	@overload
	def pingAsync(self, ip: str, callback: MethodWrapper) -> None:
		"""
		Since: 1.6.5 

		Args:
			ip: 
			callback: 
		"""
		pass

	@overload
	def cancelAllPings(self) -> None:
		"""
		Since: 1.6.5 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventDeath(BaseEvent):
	"""
	Since: 1.2.7 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

FontManager = TypeVar["net.minecraft.client.font.FontManager"]

class IMinecraftClient:

	@overload
	def jsmacros_getFontManager(self) -> FontManager:
		pass

	@overload
	def jsmacros_doItemUse(self) -> None:
		pass

	@overload
	def jsmacros_doAttack(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

ClickEvent = TypeVar["net.minecraft.text.ClickEvent"]
Runnable = TypeVar["java.lang.Runnable"]

class CustomClickEvent(ClickEvent):

	@overload
	def __init__(self, event: Runnable) -> None:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def getEvent(self) -> Runnable:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseScreen import BaseScreen
from .History import History
from .SelectCursor import SelectCursor
from .AbstractRenderCodeCompiler import AbstractRenderCodeCompiler

Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Style = TypeVar["net.minecraft.text.Style"]

class EditorScreen(BaseScreen):
	langs: List[str]
	defaultStyle: Style
	history: History
	cursor: SelectCursor
	blockFirst: bool
	textRenderTime: float
	prevChar: str
	language: str
	codeCompiler: AbstractRenderCodeCompiler

	@overload
	def __init__(self, parent: Screen, file: File) -> None:
		pass

	@overload
	def getDefaultLanguage(self) -> str:
		pass

	@overload
	def openAndScrollToIndex(self, file: File, startIndex: int, endIndex: int) -> None:
		pass

	@overload
	def openAndScrollToLine(self, file: File, line: int, col: int, endCol: int) -> None:
		pass

	@overload
	def setScroll(self, pages: float) -> None:
		pass

	@overload
	def setLanguage(self, language: str) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def copyToClipboard(self) -> None:
		pass

	@overload
	def pasteFromClipboard(self) -> None:
		pass

	@overload
	def cutToClipboard(self) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def scrollToCursor(self) -> None:
		pass

	@overload
	def save(self) -> None:
		pass

	@overload
	def needSave(self) -> bool:
		pass

	@overload
	def mouseScrolled(self, mouseX: float, mouseY: float, amount: float) -> bool:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def openParent(self) -> None:
		pass

	@overload
	def mouseClicked(self, mouseX: float, mouseY: float, btn: int) -> bool:
		pass

	@overload
	def selectWordAtCursor(self) -> None:
		pass

	@overload
	def mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> bool:
		pass

	@overload
	def updateSettings(self) -> None:
		pass

	@overload
	def charTyped(self, chr: str, keyCode: int) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .Inventory import Inventory
from .IScreen import IScreen

HandledScreen = TypeVar["net.minecraft.client.gui.screen.ingame.HandledScreen__"]

class EventOpenContainer(BaseEvent):
	"""
	Since: 1.6.5 
	"""
	inventory: Inventory
	screen: IScreen
	cancelled: bool

	@overload
	def __init__(self, screen: HandledScreen) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .AbstractMapSettingContainer_MapSettingEntry import AbstractMapSettingContainer_MapSettingEntry
from .ProfileSetting import ProfileSetting
from .ScriptTrigger import ScriptTrigger

TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class ProfileSetting_ProfileEntry(AbstractMapSettingContainer_MapSettingEntry):

	@overload
	def __init__(self, x: int, y: int, width: int, textRenderer: TextRenderer, parent: ProfileSetting, key: str, value: List[ScriptTrigger]) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MultiElementContainer import MultiElementContainer
from .AbstractMapSettingContainer import AbstractMapSettingContainer

T = TypeVar("T")
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class AbstractMapSettingContainer_MapSettingEntry(Generic[T], MultiElementContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, textRenderer: TextRenderer, parent: AbstractMapSettingContainer, key: str, value: T) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> None:
		pass

	@overload
	def setKey(self, newKey: str) -> None:
		pass

	@overload
	def setValue(self, newValue: T) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

Entity = TypeVar["net.minecraft.entity.Entity"]
CallbackInfoReturnable = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable_net.minecraft.util.ActionResult_"]
CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
BlockPos = TypeVar["net.minecraft.util.math.BlockPos"]
ClientPlayerEntity = TypeVar["net.minecraft.client.network.ClientPlayerEntity"]
BlockHitResult = TypeVar["net.minecraft.util.hit.BlockHitResult"]
Hand = TypeVar["net.minecraft.util.Hand"]
Direction = TypeVar["net.minecraft.util.math.Direction"]
PlayerEntity = TypeVar["net.minecraft.entity.player.PlayerEntity"]

class MixinClientPlayerInteractionManager:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onInteractBlock(self, player: ClientPlayerEntity, hand: Hand, hitResult: BlockHitResult, cir: CallbackInfoReturnable) -> None:
		pass

	@overload
	def onAttackBlock(self, pos: BlockPos, direction: Direction, cir: CallbackInfoReturnable) -> None:
		pass

	@overload
	def onAttackEntity(self, player: PlayerEntity, target: Entity, ci: CallbackInfo) -> None:
		pass

	@overload
	def onInteractEntity(self, player: PlayerEntity, entity: Entity, hand: Hand, cir: CallbackInfoReturnable) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .PositionCommon_Vec3D import PositionCommon_Vec3D

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class Draw3D_Box:
	pos: PositionCommon_Vec3D
	color: int
	fillColor: int
	fill: bool
	cull: bool

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool, cull: bool) -> None:
		pass

	@overload
	def __init__(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, fillColor: int, fillAlpha: int, fill: bool, cull: bool) -> None:
		pass

	@overload
	def setPos(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> None:
		"""
		Since: 1.0.6 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def setColor(self, color: int) -> None:
		"""
		Since: 1.0.6 

		Args:
			color: 
		"""
		pass

	@overload
	def setFillColor(self, fillColor: int) -> None:
		"""
		Since: 1.0.6 

		Args:
			fillColor: 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			color: 
			alpha: 
		"""
		pass

	@overload
	def setAlpha(self, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			alpha: 
		"""
		pass

	@overload
	def setFillColor(self, fillColor: int, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			fillColor: 
			alpha: 
		"""
		pass

	@overload
	def setFillAlpha(self, alpha: int) -> None:
		"""
		Since: 1.1.8 

		Args:
			alpha: 
		"""
		pass

	@overload
	def setFill(self, fill: bool) -> None:
		"""
		Since: 1.0.6 

		Args:
			fill: 
		"""
		pass

	@overload
	def render(self, matrixStack: MatrixStack) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .EntityHelper import EntityHelper

Entity = TypeVar["net.minecraft.entity.Entity"]

class EventRiding(BaseEvent):
	"""
	Since: 1.5.0 
	"""
	state: bool
	entity: EntityHelper

	@overload
	def __init__(self, state: bool, entity: Entity) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import Set
from .Core import Core
from .ServiceTrigger import ServiceTrigger
from .ServiceManager_ServiceStatus import ServiceManager_ServiceStatus
from .EventService import EventService


class ServiceManager:
	"""
	Since: 1.6.3 
	"""

	@overload
	def __init__(self, runner: Core) -> None:
		pass

	@overload
	def registerService(self, name: str, pathToFile: str) -> bool:
		"""

		Args:
			name: 
			pathToFile: relative to macro folder 

		Returns:
			false if service with that name is already registered 
		"""
		pass

	@overload
	def registerService(self, name: str, pathToFile: str, enabled: bool) -> bool:
		"""

		Args:
			name: 
			pathToFile: relative to macro folder 
			enabled: 

		Returns:
			false if service with that name is already registered 
		"""
		pass

	@overload
	def registerService(self, name: str, trigger: ServiceTrigger) -> bool:
		"""

		Args:
			name: 
			trigger: 

		Returns:
			false if service with that name already registered 
		"""
		pass

	@overload
	def unregisterService(self, name: str) -> bool:
		"""

		Args:
			name: 
		"""
		pass

	@overload
	def renameService(self, oldName: str, newName: str) -> bool:
		"""

		Args:
			newName: 
			oldName: 

		Returns:
			false if service with new name already registered or old name doesn't exist 
		"""
		pass

	@overload
	def getServices(self) -> Set[str]:
		"""

		Returns:
			registered service names 
		"""
		pass

	@overload
	def startService(self, name: str) -> ServiceManager_ServiceStatus:
		"""starts service once

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def stopService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def restartService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			state before "restarting" (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def enableService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def disableService(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			previous state (or ServiceManager_ServiceStatus#UNKNOWN if unknown service) 
		"""
		pass

	@overload
	def status(self, name: str) -> ServiceManager_ServiceStatus:
		"""

		Args:
			name: service name 

		Returns:
			ServiceManager_ServiceStatus#UNKNOWN if unknown service, ServiceManager_ServiceStatus#RUNNING if disabled and running, ServiceManager_ServiceStatus#DISABLED if disabled and stopped, ServiceManager_ServiceStatus#STOPPED if enabled and stopped, ServiceManager_ServiceStatus#ENABLED if enabled and running. 
		"""
		pass

	@overload
	def getServiceData(self, name: str) -> EventService:
		"""this might throw if the service is not running...\n
		Since: 1.6.5 

		Args:
			name: 

		Returns:
			the event that is current for the service 
		"""
		pass

	@overload
	def getTrigger(self, name: str) -> ServiceTrigger:
		"""
		Since: 1.6.5 [named getServiceData previously] 

		Args:
			name: 
		"""
		pass

	@overload
	def load(self) -> None:
		"""load services from config
		"""
		pass

	@overload
	def save(self) -> None:
		"""save current registered services enabled/disabled status to config
		"""
		pass

	pass





from typing import overload
from typing import List
from .PerExecLibrary import PerExecLibrary
from .BaseScriptContext import BaseScriptContext
from .FileHandler import FileHandler


class FFS(PerExecLibrary):
	"""Better File-System functions.

An instance of this class is passed to scripts as the 'FS' variable.\n
	Since: 1.1.8 
	"""

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def list(self, path: str) -> List[str]:
		"""List files in path.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			An array of file names as String . 
		"""
		pass

	@overload
	def exists(self, path: str) -> bool:
		"""Check if a file exists.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 
		"""
		pass

	@overload
	def isDir(self, path: str) -> bool:
		"""Check if a file is a directory.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 
		"""
		pass

	@overload
	def getName(self, path: str) -> str:
		"""Get the last part (name) of a file.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a String of the file name. 
		"""
		pass

	@overload
	def makeDir(self, path: str) -> bool:
		"""Make a directory.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a Boolean for success. 
		"""
		pass

	@overload
	def move(self, from_: str, to: str) -> None:
		"""Move a file.\n
		Since: 1.1.8 

		Args:
			from: relative to the script's folder. 
			to: relative to the script's folder. 
		"""
		pass

	@overload
	def copy(self, from_: str, to: str) -> None:
		"""Copy a file.\n
		Since: 1.1.8 

		Args:
			from: relative to the script's folder. 
			to: relative to the script's folder. 
		"""
		pass

	@overload
	def unlink(self, path: str) -> bool:
		"""Delete a file.\n
		Since: 1.2.9 

		Args:
			path: relative to the script's folder. 

		Returns:
			a Boolean for success. 
		"""
		pass

	@overload
	def combine(self, patha: str, pathb: str) -> str:
		"""Combine 2 paths.\n
		Since: 1.1.8 

		Args:
			patha: path is relative to the script's folder. 
			pathb: 

		Returns:
			a String of the combined path. 
		"""
		pass

	@overload
	def getDir(self, path: str) -> str:
		"""Gets the directory part of a file path, or the parent directory of a folder.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a String of the combined path. 
		"""
		pass

	@overload
	def open(self, path: str) -> FileHandler:
		"""Open a FileHandler for the file at the specified path.\n
		Since: 1.1.8 

		Args:
			path: relative to the script's folder. 

		Returns:
			a FileHandler for the file path. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .IHorseScreen import IHorseScreen

Entity = TypeVar["net.minecraft.entity.Entity"]

class MixinHorseScreen(IHorseScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getEntity(self) -> Entity:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

Consumer = TypeVar["java.util.function.Consumer_java.lang.Integer_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class SelectorDropdownOverlay(OverlayContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, choices: List[Text], textRenderer: TextRenderer, parent: IOverlayParent, onChoice: Consumer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def onScroll(self, page: float) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float, button: int) -> None:
		pass

	@overload
	def setSelected(self, sel: int) -> None:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .AbstractMapSettingContainer import AbstractMapSettingContainer
from .SettingsOverlay import SettingsOverlay
from .ScriptTrigger import ScriptTrigger

TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class ProfileSetting(AbstractMapSettingContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: SettingsOverlay, group: List[str]) -> None:
		pass

	@overload
	def addField(self, key: str, value: List[ScriptTrigger]) -> None:
		pass

	@overload
	def removeField(self, key: str) -> None:
		pass

	@overload
	def changeKey(self, key: str, newKey: str) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Button import Button

Consumer = TypeVar["java.util.function.Consumer_xyz.wagyourtail.wagyourgui.elements.Button_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class AnnotatedCheckBox(Button):
	value: bool

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, color: int, borderColor: int, hilightColor: int, textColor: int, message: Text, initialValue: bool, onPress: Consumer) -> None:
		pass

	@overload
	def onPress(self) -> None:
		pass

	@overload
	def setMessage(self, message: Text) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

T = TypeVar("T")
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class ButtonWidgetHelper(RenderCommon_RenderElement, Generic[T], BaseHelper):
	"""
	Since: 1.0.5 
	"""
	zIndex: int

	@overload
	def __init__(self, btn: T) -> None:
		pass

	@overload
	def __init__(self, btn: T, zIndex: int) -> None:
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.0.5 

		Returns:
			the 'x' coordinate of the button. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.0.5 

		Returns:
			the 'y' coordinate of the button. 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> "ButtonWidgetHelper":
		"""Set the button position.\n
		Since: 1.0.5 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def setLabel(self, label: str) -> "ButtonWidgetHelper":
		"""change the text.\n
		Since: 1.0.5, renamed from 'setText' in 1.3.1 

		Args:
			label: 
		"""
		pass

	@overload
	def setLabel(self, helper: TextHelper) -> "ButtonWidgetHelper":
		"""change the text.\n
		Since: 1.3.1 

		Args:
			helper: 
		"""
		pass

	@overload
	def getLabel(self) -> TextHelper:
		"""
		Since: 1.2.3, renamed fro 'getText' in 1.3.1 

		Returns:
			current button text. 
		"""
		pass

	@overload
	def getActive(self) -> bool:
		"""
		Since: 1.0.5 

		Returns:
			button clickable state. 
		"""
		pass

	@overload
	def setActive(self, t: bool) -> "ButtonWidgetHelper":
		"""set the button clickable state.\n
		Since: 1.0.5 

		Args:
			t: 
		"""
		pass

	@overload
	def setWidth(self, width: int) -> "ButtonWidgetHelper":
		"""set the button width.\n
		Since: 1.0.5 

		Args:
			width: 
		"""
		pass

	@overload
	def click(self) -> "ButtonWidgetHelper":
		"""clicks button\n
		Since: 1.3.1 
		"""
		pass

	@overload
	def click(self, await_: bool) -> "ButtonWidgetHelper":
		"""clicks button\n
		Since: 1.3.1 

		Args:
			await: should wait for button to finish clicking. 
		"""
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .ScoreboardObjectiveHelper import ScoreboardObjectiveHelper
from .PlayerEntityHelper import PlayerEntityHelper
from .TeamHelper import TeamHelper

Scoreboard = TypeVar["net.minecraft.scoreboard.Scoreboard"]

class ScoreboardsHelper(BaseHelper):
	"""
	Since: 1.2.9 
	"""

	@overload
	def __init__(self, board: Scoreboard) -> None:
		pass

	@overload
	def getObjectiveForTeamColorIndex(self, index: int) -> ScoreboardObjectiveHelper:
		"""
		Since: 1.2.9 

		Args:
			index: 
		"""
		pass

	@overload
	def getObjectiveSlot(self, slot: int) -> ScoreboardObjectiveHelper:
		"""'0' is tab list, '1' or '3 + getPlayerTeamColorIndex()' is sidebar, '2' should be below name.
therefore max slot number is 18.\n
		Since: 1.2.9 

		Args:
			slot: 
		"""
		pass

	@overload
	def getPlayerTeamColorIndex(self, entity: PlayerEntityHelper) -> int:
		"""
		Since: 1.2.9 

		Args:
			entity: 
		"""
		pass

	@overload
	def getPlayerTeamColorIndex(self) -> int:
		"""
		Since: 1.6.5 

		Returns:
			team index for client player 
		"""
		pass

	@overload
	def getTeams(self) -> List[TeamHelper]:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getPlayerTeam(self, p: PlayerEntityHelper) -> TeamHelper:
		"""
		Since: 1.3.0 

		Args:
			p: 
		"""
		pass

	@overload
	def getPlayerTeam(self) -> TeamHelper:
		"""
		Since: 1.6.5 

		Returns:
			team for client player 
		"""
		pass

	@overload
	def getCurrentScoreboard(self) -> ScoreboardObjectiveHelper:
		"""
		Since: 1.2.9 

		Returns:
			the ScoreboardObjectiveHelper for the currently displayed sidebar scoreboard. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .NBTElementHelper import NBTElementHelper


class NBTElementHelper_NBTListHelper(NBTElementHelper):
	"""
	Since: 1.5.1 
	"""

	@overload
	def length(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def get(self, index: int) -> NBTElementHelper:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def getHeldType(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .IEventListener import IEventListener
from .MethodWrapper import MethodWrapper

Thread = TypeVar["java.lang.Thread"]

class FJsMacros_ScriptEventListener(IEventListener):

	@overload
	def getCreator(self) -> Thread:
		pass

	@overload
	def getWrapper(self) -> MethodWrapper:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .TextHelper import TextHelper

Text = TypeVar["net.minecraft.text.Text"]

class EventDisconnect(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	message: TextHelper

	@overload
	def __init__(self, message: Text) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .PlayerListEntryHelper import PlayerListEntryHelper

PlayerListEntry = TypeVar["net.minecraft.client.network.PlayerListEntry"]
UUID = TypeVar["java.util.UUID"]

class EventPlayerJoin(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	UUID: str
	player: PlayerListEntryHelper

	@overload
	def __init__(self, uuid: UUID, player: PlayerListEntry) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .Button import Button

File = TypeVar["java.io.File"]

class FileChooser_fileObj:
	file: File
	btn: Button

	@overload
	def __init__(self, file: File, btn: Button) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .PositionCommon_Pos3D import PositionCommon_Pos3D

Function = TypeVar["java.util.function.Function_xyz.wagyourtail.jsmacros.client.api.helpers.BlockStateHelper,java.lang.Boolean_"]
ChunkPos = TypeVar["net.minecraft.util.math.ChunkPos"]
World = TypeVar["net.minecraft.world.World"]

class WorldScanner:
	"""A class to scan the world for certain blocks. The results of the filters are cached, 
so it's a good idea to reuse an instance of this if possible. 
The scanner can either return a list of all block positions or
a list of blocks and their respective count for every block / state matching the filters criteria.\n
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, world: World, blockFilter: Function, stateFilter: Function) -> None:
		"""Creates a new World scanner with for the given world. It accepts two boolean functions, 
one for BlockHelper and the other for BlockStateHelper .

		Args:
			world: 
			blockFilter: 
			stateFilter: 
		"""
		pass

	@overload
	def getChunkRange(self, centerX: int, centerZ: int, chunkrange: int) -> List[ChunkPos]:
		"""Gets a list of all chunks in the given range around the center chunk.

		Args:
			centerZ: 
			centerX: 
			chunkrange: 
		"""
		pass

	@overload
	def scanAroundPlayer(self, range: int) -> List[PositionCommon_Pos3D]:
		"""Scans all chunks in the given range around the player and returns a list of all block positions, for blocks matching the filter.
This will scan in a square with length 2*range + 1. So range = 0 for example will only scan the chunk the player
is standing in, while range = 1 will scan in a 3x3 area.

		Args:
			range: 
		"""
		pass

	@overload
	def scanChunkRange(self, centerX: int, centerZ: int, chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""Scans all chunks in the given range around the center chunk and returns a list of all block positions, for blocks matching the filter.
This will scan in a square with length 2*range + 1. So range = 0 for example will only scan the specified chunk,
while range = 1 will scan in a 3x3 area.

		Args:
			centerZ: 
			centerX: 
			chunkrange: 

		Returns:
			the list 
		"""
		pass

	@overload
	def getBlocksInChunk(self, chunkX: int, chunkZ: int, ignoreState: bool) -> Mapping[str, int]:
		"""Gets the amount of all blocks matching the criteria inside the chunk.

		Args:
			ignoreState: whether multiple states should be combined to a single block 
			chunkX: 
			chunkZ: 
		"""
		pass

	@overload
	def getBlocksInChunks(self, centerX: int, centerZ: int, chunkrange: int, ignoreState: bool) -> Mapping[str, int]:
		"""Gets the amount of all blocks matching the criteria inside square around the center chunk 
with radius chunkrange/2.

		Args:
			centerZ: 
			ignoreState: whether multiple states should be combined to a single block 
			centerX: 
			chunkrange: 
		"""
		pass

	@overload
	def getCachedAmount(self) -> int:
		"""Get the amount of cached block states. This will normally be around 200 - 400.
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

Entity = TypeVar["net.minecraft.entity.Entity"]
Entity_RemovalReason = TypeVar["net.minecraft.entity.Entity.RemovalReason"]
CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]

class MixinClientWorld:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onAddEntity(self, id: int, entity: Entity, ci: CallbackInfo) -> None:
		pass

	@overload
	def onRemoveEntity(self, entityId: int, removalReason: Entity_RemovalReason, ci: CallbackInfo, entity: Entity) -> None:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventJoinedTick(BaseEvent):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .EventFallFlying import EventFallFlying
from .EventDisconnect import EventDisconnect
from .EventInteractBlock import EventInteractBlock
from .EventEXPChange import EventEXPChange
from .EventCustom import EventCustom
from .EventRecvMessage import EventRecvMessage
from .EventHeal import EventHeal
from .EventWrappedScript import EventWrappedScript
from .EventInteractEntity import EventInteractEntity
from .EventAirChange import EventAirChange
from .EventBlockUpdate import EventBlockUpdate
from .CodeCompileEvent import CodeCompileEvent
from .EventEntityHealed import EventEntityHealed
from .EventClickSlot import EventClickSlot
from .EventResourcePackLoaded import EventResourcePackLoaded
from .EventItemDamage import EventItemDamage
from .EventDimensionChange import EventDimensionChange
from .EventJoinedTick import EventJoinedTick
from .EventItemPickup import EventItemPickup
from .EventOpenScreen import EventOpenScreen
from .EventTitle import EventTitle
from .EventDeath import EventDeath
from .EventAttackEntity import EventAttackEntity
from .EventSignEdit import EventSignEdit
from .CommandContextHelper import CommandContextHelper
from .EventSendMessage import EventSendMessage
from .EventTick import EventTick
from .EventSound import EventSound
from .EventKey import EventKey
from .EventOpenContainer import EventOpenContainer
from .EventProfileLoad import EventProfileLoad
from .EventBossbar import EventBossbar
from .EventAttackBlock import EventAttackBlock
from .EventService import EventService
from .EventDamage import EventDamage
from .EventEntityLoad import EventEntityLoad
from .EventPlayerLeave import EventPlayerLeave
from .EventChunkLoad import EventChunkLoad
from .EventChunkUnload import EventChunkUnload
from .EventHungerChange import EventHungerChange
from .EventDropSlot import EventDropSlot
from .EventArmorChange import EventArmorChange
from .EventRiding import EventRiding
from .EventPlayerJoin import EventPlayerJoin
from .EventJoinServer import EventJoinServer
from .EventEntityUnload import EventEntityUnload
from .EventEntityDamaged import EventEntityDamaged
from .EventHeldItemChange import EventHeldItemChange

File = TypeVar["java.io.File"]




from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .NBTElementHelper import NBTElementHelper

ItemStack = TypeVar["net.minecraft.item.ItemStack"]

class ItemStackHelper(BaseHelper):
	"""
	"""

	@overload
	def __init__(self, i: ItemStack) -> None:
		pass

	@overload
	def setDamage(self, damage: int) -> "ItemStackHelper":
		"""Sets the item damage value.

You may want to use ItemStackHelper#copy() first.\n
		Since: 1.2.0 

		Args:
			damage: 
		"""
		pass

	@overload
	def isDamageable(self) -> bool:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def isEnchantable(self) -> bool:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def getDamage(self) -> int:
		"""
		"""
		pass

	@overload
	def getMaxDamage(self) -> int:
		"""
		"""
		pass

	@overload
	def getDefaultName(self) -> TextHelper:
		"""
		Since: 1.2.0 

		Returns:
			was string before 1.6.5 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""

		Returns:
			was string before 1.6.5 
		"""
		pass

	@overload
	def getCount(self) -> int:
		"""
		"""
		pass

	@overload
	def getMaxCount(self) -> int:
		"""
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper:
		"""
		Since: 1.1.6, was a String until 1.5.1 
		"""
		pass

	@overload
	def getCreativeTab(self) -> str:
		"""
		Since: 1.1.3 
		"""
		pass

	@overload
	def getItemID(self) -> str:
		"""
		"""
		pass

	@overload
	def getItemId(self) -> str:
		"""
		Since: 1.6.4 
		"""
		pass

	@overload
	def getTags(self) -> List[str]:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isFood(self) -> bool:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isTool(self) -> bool:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isWearable(self) -> bool:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def getMiningLevel(self) -> int:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def isEmpty(self) -> bool:
		"""
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def equals(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def equals(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isItemEqual(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def isItemEqual(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isItemEqualIgnoreDamage(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def isItemEqualIgnoreDamage(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isNBTEqual(self, ish: "ItemStackHelper") -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			ish: 
		"""
		pass

	@overload
	def isNBTEqual(self, is_: ItemStack) -> bool:
		"""
		Since: 1.1.3 [citation needed] 

		Args:
			is: 
		"""
		pass

	@overload
	def isOnCooldown(self) -> bool:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getCooldownProgress(self) -> float:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def copy(self) -> "ItemStackHelper":
		"""
		Since: 1.2.0 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .IContainerParent import IContainerParent

Consumer = TypeVar["java.util.function.Consumer_java.lang.Boolean_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class CheckBoxContainer(MultiElementContainer):
	message: Text

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, defaultState: bool, message: Text, parent: IContainerParent, setState: Consumer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

WebSocketFrame = TypeVar["com.neovisionaries.ws.client.WebSocketFrame"]

class Websocket_Disconnected:
	"""
	"""
	serverFrame: WebSocketFrame
	clientFrame: WebSocketFrame
	isServer: bool

	@overload
	def __init__(self, serverFrame: WebSocketFrame, clientFrame: WebSocketFrame, isServer: bool) -> None:
		"""

		Args:
			isServer: 
			clientFrame: 
			serverFrame: 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer


class FJsMacros_EventAndContext:
	event: BaseEvent
	context: EventContainer

	@overload
	def __init__(self, event: BaseEvent, context: EventContainer) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MacroScreen import MacroScreen

Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]

class KeyMacrosScreen(MacroScreen):

	@overload
	def __init__(self, parent: Screen) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def keyReleased(self, keyCode: int, scanCode: int, modifiers: int) -> bool:
		pass

	@overload
	def mouseReleased(self, mouseX: float, mouseY: float, button: int) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar

ClickEvent_Action = TypeVar["net.minecraft.text.ClickEvent.Action"]

class MixinStyleSerializer:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def redirectClickGetAction(self, action: ClickEvent_Action) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

WorldTimeUpdateS2CPacket = TypeVar["net.minecraft.network.packet.s2c.play.WorldTimeUpdateS2CPacket"]
CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
GameJoinS2CPacket = TypeVar["net.minecraft.network.packet.s2c.play.GameJoinS2CPacket"]

class MixinClientPlayNetworkHandler:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onServerTime(self, packet: WorldTimeUpdateS2CPacket, info: CallbackInfo) -> None:
		pass

	@overload
	def onGameJoin(self, packet: GameJoinS2CPacket, info: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
from .MacroScreen import MacroScreen

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class MacroListTopbar(MultiElementContainer):
	deftype: ScriptTrigger_TriggerType

	@overload
	def __init__(self, parent: MacroScreen, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, deftype: ScriptTrigger_TriggerType) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def updateType(self, type: ScriptTrigger_TriggerType) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

Team = TypeVar["net.minecraft.scoreboard.Team"]

class TeamHelper(BaseHelper):
	"""
	Since: 1.3.0 
	"""

	@overload
	def __init__(self, t: Team) -> None:
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getDisplayName(self) -> TextHelper:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getPlayerList(self) -> List[str]:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getPrefix(self) -> TextHelper:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getSuffix(self) -> TextHelper:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def getCollisionRule(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def isFriendlyFire(self) -> bool:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def showFriendlyInvisibles(self) -> bool:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def nametagVisibility(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def deathMessageVisibility(self) -> str:
		"""
		Since: 1.3.0 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .BlockDataHelper import BlockDataHelper

BlockState = TypeVar["net.minecraft.block.BlockState"]
BlockPos = TypeVar["net.minecraft.util.math.BlockPos"]
BlockEntity = TypeVar["net.minecraft.block.entity.BlockEntity"]

class EventBlockUpdate(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	block: BlockDataHelper
	updateType: str

	@overload
	def __init__(self, block: BlockState, blockEntity: BlockEntity, blockPos: BlockPos, updateType: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .RenderCommon_Text import RenderCommon_Text
from .RenderCommon_Rect import RenderCommon_Rect
from .RenderCommon_Item import RenderCommon_Item
from .RenderCommon_Image import RenderCommon_Image
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .MethodWrapper import MethodWrapper

T = TypeVar("T")
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class IDraw2D:
	"""
	Since: 1.2.7 
	"""

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.2.7 

		Returns:
			screen width 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.2.7 

		Returns:
			screen height 
		"""
		pass

	@overload
	def getTexts(self) -> List[RenderCommon_Text]:
		"""
		Since: 1.2.7 

		Returns:
			text elements 
		"""
		pass

	@overload
	def getRects(self) -> List[RenderCommon_Rect]:
		"""
		Since: 1.2.7 

		Returns:
			rect elements 
		"""
		pass

	@overload
	def getItems(self) -> List[RenderCommon_Item]:
		"""
		Since: 1.2.7 

		Returns:
			item elements 
		"""
		pass

	@overload
	def getImages(self) -> List[RenderCommon_Image]:
		"""
		Since: 1.2.7 

		Returns:
			image elements 
		"""
		pass

	@overload
	def getElements(self) -> List[RenderCommon_RenderElement]:
		"""
		Since: 1.2.9 

		Returns:
			a read only copy of the list of all elements added by scripts. 
		"""
		pass

	@overload
	def removeElement(self, e: RenderCommon_RenderElement) -> T:
		"""removes any element regardless of type.\n
		Since: 1.2.9 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def reAddElement(self, e: RenderCommon_RenderElement) -> RenderCommon_RenderElement:
		"""re-add an element you removed with IDraw2D#removeElement(xyz.wagyourtail.jsmacros.client.api.sharedclasses.RenderCommon.RenderElement)\n
		Since: 1.2.9 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool) -> RenderCommon_Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool) -> RenderCommon_Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool) -> RenderCommon_Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool) -> RenderCommon_Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			x: screen x 
			y: screen y 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		"""
		Since: 1.2.7 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 

		Returns:
			added text 
		"""
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		"""
		Since: 1.4.0 

		Args:
			color: text color 
			shadow: include shadow layer 
			rotation: text rotation (as degrees) 
			x: screen x 
			y: screen y 
			scale: text scale (as double) 
			text: 
			zIndex: z-index 

		Returns:
			added text 
		"""
		pass

	@overload
	def removeText(self, t: RenderCommon_Text) -> T:
		"""
		Since: 1.2.7 

		Args:
			t: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> RenderCommon_Image:
		"""
		Since: 1.2.7 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			height: height on screen 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> RenderCommon_Image:
		"""
		Since: 1.4.0 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			height: height on screen 
			zIndex: z-index 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.2.7 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			rotation: the rotation of the texture (as degrees) 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			height: height on screen 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.4.0 

		Args:
			imageY: the top-most coordinate of the texture region 
			textureWidth: the width of the entire texture 
			imageX: the left-most coordinate of the texture region 
			rotation: the rotation of the texture (as degrees) 
			regionWidth: the width the texture region 
			textureHeight: the height of the entire texture 
			x: screen x, top left corner 
			width: width on screen 
			y: screen y, top left corner 
			regionHeight: the height the texture region 
			id: image id, in the form 'minecraft:textures' path'd as found in texture packs, ie 'assets/minecraft/textures/gui/recipe_book.png' becomes 'minecraft:textures/gui/recipe_book.png' 
			height: height on screen 
			zIndex: z-index 

		Returns:
			added image 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.6.5 

		Args:
			color: 
			imageY: 
			textureWidth: 
			imageX: 
			rotation: 
			regionWidth: 
			textureHeight: 
			x: 
			width: 
			y: 
			regionHeight: 
			id: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.6.5 

		Args:
			color: 
			imageY: 
			textureWidth: 
			imageX: 
			rotation: 
			regionWidth: 
			textureHeight: 
			alpha: 
			x: 
			width: 
			y: 
			regionHeight: 
			id: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def removeImage(self, i: RenderCommon_Image) -> T:
		"""
		Since: 1.2.7 

		Args:
			i: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> RenderCommon_Rect:
		"""
		Since: 1.2.7 

		Args:
			color: as hex, with alpha channel 
			y1: 
			x1: 
			y2: 
			x2: 

		Returns:
			added rect 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> RenderCommon_Rect:
		"""
		Since: 1.2.7 

		Args:
			color: as hex 
			alpha: alpha channel 0-255 
			y1: 
			x1: 
			y2: 
			x2: 

		Returns:
			added rect 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> RenderCommon_Rect:
		"""
		Since: 1.2.7 

		Args:
			color: as hex 
			alpha: alpha channel 0-255 
			rotation: as degrees 
			y1: 
			x1: 
			y2: 
			x2: 

		Returns:
			added rect 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> RenderCommon_Rect:
		"""
		Since: 1.4.0 

		Args:
			color: as hex 
			alpha: alpha channel 0-255 
			rotation: as degrees 
			y1: 
			x1: 
			y2: 
			x2: 
			zIndex: z-index 

		Returns:
			added rect 
		"""
		pass

	@overload
	def removeRect(self, r: RenderCommon_Rect) -> T:
		"""
		Since: 1.2.7 

		Args:
			r: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> RenderCommon_Item:
		"""
		Since: 1.2.7 

		Args:
			x: left most corner 
			y: top most corner 
			id: item id 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str) -> RenderCommon_Item:
		"""
		Since: 1.4.0 

		Args:
			x: left most corner 
			y: top most corner 
			id: item id 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.2.7 

		Args:
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 
			id: item id 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.4.0 

		Args:
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 
			id: item id 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.2.7 

		Args:
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 
			id: item id 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.4.0 

		Args:
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 
			id: item id 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper) -> RenderCommon_Item:
		"""
		Since: 1.2.7 

		Args:
			item: from inventory as helper 
			x: left most corner 
			y: top most corner 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper) -> RenderCommon_Item:
		"""
		Since: 1.4.0 

		Args:
			item: from inventory as helper 
			x: left most corner 
			y: top most corner 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.2.7 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.4.0 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			x: left most corner 
			y: top most corner 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.2.7 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 

		Returns:
			added item 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.4.0 

		Args:
			item: from inventory as helper 
			overlay: should include overlay health and count 
			rotation: rotation of item 
			x: left most corner 
			y: top most corner 
			scale: scale of item 
			zIndex: z-index 

		Returns:
			added item 
		"""
		pass

	@overload
	def removeItem(self, i: RenderCommon_Item) -> T:
		"""
		Since: 1.2.7 

		Args:
			i: 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setOnInit(self, onInit: MethodWrapper) -> T:
		"""
		Since: 1.2.7 

		Args:
			onInit: calls your method as a Consumer IDraw2D#T 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setOnFailInit(self, catchInit: MethodWrapper) -> T:
		"""
		Since: 1.2.7 

		Args:
			catchInit: calls your method as a Consumer String 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def render(self, matrixStack: MatrixStack) -> None:
		"""internal

		Args:
			matrixStack: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .Draw2D import Draw2D
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .PositionCommon_Pos2D import PositionCommon_Pos2D

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class Draw3D_Surface(Draw2D):
	"""
	Since: 1.6.5 
	"""
	pos: PositionCommon_Pos3D
	rotations: PositionCommon_Pos3D
	zIndexScale: float
	renderBack: bool
	cull: bool

	@overload
	def __init__(self, pos: PositionCommon_Pos3D, rotations: PositionCommon_Pos3D, sizes: PositionCommon_Pos2D, minSubdivisions: int, renderBack: bool, cull: bool) -> None:
		pass

	@overload
	def setPos(self, x: float, y: float, z: float) -> None:
		pass

	@overload
	def setRotations(self, x: float, y: float, z: float) -> None:
		pass

	@overload
	def setSizes(self, x: float, y: float) -> None:
		pass

	@overload
	def getSizes(self) -> PositionCommon_Pos2D:
		pass

	@overload
	def setMinSubdivisions(self, minSubdivisions: int) -> None:
		pass

	@overload
	def getMinSubdivisions(self) -> int:
		pass

	@overload
	def getHeight(self) -> int:
		pass

	@overload
	def getWidth(self) -> int:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def render3D(self, matrixStack: MatrixStack) -> None:
		pass

	@overload
	def render(self, matrixStack: MatrixStack) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .ItemStackHelper import ItemStackHelper

ItemStack = TypeVar["net.minecraft.item.ItemStack"]

class EventItemDamage(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	item: ItemStackHelper
	damage: int

	@overload
	def __init__(self, stack: ItemStack, damage: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer


class IEventListener:

	@overload
	def trigger(self, event: BaseEvent) -> EventContainer:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseEvent import BaseEvent
from .TextHelper import TextHelper

MessageIndicator = TypeVar["net.minecraft.client.gui.hud.MessageIndicator"]
MessageSignatureData = TypeVar["net.minecraft.network.message.MessageSignatureData"]
Text = TypeVar["net.minecraft.text.Text"]

class EventRecvMessage(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	text: TextHelper
	signature: List[float]
	messageType: str

	@overload
	def __init__(self, message: Text, signature: MessageSignatureData, indicator: MessageIndicator) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .BaseHelper import BaseHelper
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .PositionCommon_Pos2D import PositionCommon_Pos2D
from .TextHelper import TextHelper
from .NBTElementHelper import NBTElementHelper
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
from .PlayerEntityHelper import PlayerEntityHelper
from .VillagerEntityHelper import VillagerEntityHelper
from .MerchantEntityHelper import MerchantEntityHelper
from .LivingEntityHelper import LivingEntityHelper
from .ItemEntityHelper import ItemEntityHelper

Entity = TypeVar["net.minecraft.entity.Entity"]
T = TypeVar("T")

class EntityHelper(Generic[T], BaseHelper):
	"""
	"""

	@overload
	def getPos(self) -> PositionCommon_Pos3D:
		"""

		Returns:
			entity position. 
		"""
		pass

	@overload
	def getBlockPos(self) -> PositionCommon_Pos3D:
		"""
		Since: 1.6.5 

		Returns:
			entity block position. 
		"""
		pass

	@overload
	def getChunkPos(self) -> PositionCommon_Pos2D:
		"""
		Since: 1.6.5 

		Returns:
			entity chunk coordinates. Since Pos2D only has x and y fields, z coord is y. 
		"""
		pass

	@overload
	def getX(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'x' value of the entity. 
		"""
		pass

	@overload
	def getY(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'y' value of the entity. 
		"""
		pass

	@overload
	def getZ(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'z' value of the entity. 
		"""
		pass

	@overload
	def getEyeHeight(self) -> float:
		"""
		Since: 1.2.8 

		Returns:
			the current eye height offset for the entitye. 
		"""
		pass

	@overload
	def getPitch(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'pitch' value of the entity. 
		"""
		pass

	@overload
	def getYaw(self) -> float:
		"""
		Since: 1.0.8 

		Returns:
			the 'yaw' value of the entity. 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""
		Since: 1.0.8 [citation needed], returned string until 1.6.4 

		Returns:
			the name of the entity. 
		"""
		pass

	@overload
	def getType(self) -> str:
		"""

		Returns:
			the type of the entity. 
		"""
		pass

	@overload
	def isGlowing(self) -> bool:
		"""
		Since: 1.1.9 

		Returns:
			if the entity has the glowing effect. 
		"""
		pass

	@overload
	def isInLava(self) -> bool:
		"""
		Since: 1.1.9 

		Returns:
			if the entity is in lava. 
		"""
		pass

	@overload
	def isOnFire(self) -> bool:
		"""
		Since: 1.1.9 

		Returns:
			if the entity is on fire. 
		"""
		pass

	@overload
	def getVehicle(self) -> "EntityHelper":
		"""
		Since: 1.1.8 [citation needed] 

		Returns:
			the vehicle of the entity. 
		"""
		pass

	@overload
	def getPassengers(self) -> List["EntityHelper"]:
		"""
		Since: 1.1.8 [citation needed] 

		Returns:
			the entity passengers. 
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper:
		"""
		Since: 1.2.8, was a String until 1.5.0 
		"""
		pass

	@overload
	def setCustomName(self, name: TextHelper) -> None:
		"""
		Since: 1.6.4 

		Args:
			name: 
		"""
		pass

	@overload
	def setCustomNameVisible(self, b: bool) -> None:
		"""sets the name to always display\n
		Since: 1.8.0 

		Args:
			b: 
		"""
		pass

	@overload
	def setGlowingColor(self, color: int) -> None:
		"""

		Args:
			color: 
		"""
		pass

	@overload
	def resetGlowingColor(self) -> None:
		"""
		"""
		pass

	@overload
	def getGlowingColor(self) -> int:
		"""warning: affected by setGlowingColor\n
		Since: 1.8.2 

		Returns:
			glow color 
		"""
		pass

	@overload
	def setGlowing(self, val: bool) -> "EntityHelper":
		"""Sets whether the entity is glowing.\n
		Since: 1.1.9 

		Args:
			val: 
		"""
		pass

	@overload
	def resetGlowing(self) -> "EntityHelper":
		"""reset the glowing effect to proper value.\n
		Since: 1.6.3 
		"""
		pass

	@overload
	def isAlive(self) -> bool:
		"""Checks if the entity is still alive.\n
		Since: 1.2.8 
		"""
		pass

	@overload
	def getUUID(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			UUID of the entity, random* if not a player, otherwise the player's uuid. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def create(self, e: Entity) -> "EntityHelper":
		"""mostly for internal use.

		Args:
			e: mc entity. 

		Returns:
			correct subclass of this. 
		"""
		pass

	@overload
	def asClientPlayer(self) -> ClientPlayerEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asPlayer(self) -> PlayerEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asVillager(self) -> VillagerEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asMerchant(self) -> MerchantEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asLiving(self) -> LivingEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	@overload
	def asItem(self) -> ItemEntityHelper:
		"""
		Since: 1.6.3 

		Returns:
			cast of this entity helper (mainly for typescript) 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .MethodWrapper import MethodWrapper
from .ClassBuilder_FieldBuilder import ClassBuilder_FieldBuilder
from .ClassBuilder_MethodBuilder import ClassBuilder_MethodBuilder
from .ClassBuilder_ConstructorBuilder import ClassBuilder_ConstructorBuilder
from .ClassBuilder_AnnotationBuilder import ClassBuilder_AnnotationBuilder

T = TypeVar("T")

class ClassBuilder(Generic[T]):
	"""
	Since: 1.6.5 
	"""
	methodWrappers: Mapping[str, MethodWrapper]
	ctClass: CtClass

	@overload
	def __init__(self, name: str, parent: Class, interfaces: List[Class]) -> None:
		pass

	@overload
	def addField(self, fieldType: Class, name: str) -> "ClassBuilder_FieldBuilder":
		pass

	@overload
	def addMethod(self, returnType: Class, name: str, params: List[Class]) -> "ClassBuilder_MethodBuilder":
		pass

	@overload
	def addConstructor(self, params: List[Class]) -> "ClassBuilder_ConstructorBuilder":
		pass

	@overload
	def addClinit(self) -> "ClassBuilder_ConstructorBuilder":
		pass

	@overload
	def addAnnotation(self, type: Class) -> "ClassBuilder_AnnotationBuilder":
		pass

	@overload
	def finishBuildAndFreeze(self) -> Class:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

Serializable = TypeVar["java.io.Serializable"]
E = TypeVar("E")
AbstractSet = TypeVar["java.util.AbstractSet_E_"]

class SynchronizedWeakHashSet(Serializable, Generic[E], AbstractSet):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def size(self) -> int:
		pass

	@overload
	def contains(self, o: object) -> bool:
		pass

	@overload
	def add(self, o: E) -> bool:
		pass

	@overload
	def remove(self, o: object) -> bool:
		pass

	@overload
	def clear(self) -> None:
		pass

	@overload
	def iterator(self) -> iter:
		pass

	pass





from typing import overload
from typing import TypeVar

CommandNode = TypeVar["com.mojang.brigadier.tree.CommandNode_S_"]

class CommandNodeAccessor:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def remove(self, parent: CommandNode, name: str) -> CommandNode:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

Function = TypeVar["java.util.function.Function_java.lang.Object[],java.lang.Object_"]
T = TypeVar("T")

class ProxyBuilder_ProxyReference(Generic[T]):
	self: T
	parent: Function

	@overload
	def __init__(self, self: T, parent: Function) -> None:
		pass

	pass





from typing import overload
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .PositionCommon_Vec2D import PositionCommon_Vec2D


class PositionCommon_Pos2D:
	"""
	Since: 1.2.6 [citation needed] 
	"""
	ZERO: "PositionCommon_Pos2D"
	x: float
	y: float

	@overload
	def __init__(self, x: float, y: float) -> None:
		pass

	@overload
	def getX(self) -> float:
		pass

	@overload
	def getY(self) -> float:
		pass

	@overload
	def add(self, pos: "PositionCommon_Pos2D") -> "PositionCommon_Pos2D":
		pass

	@overload
	def add(self, x: float, y: float) -> "PositionCommon_Pos2D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def multiply(self, pos: "PositionCommon_Pos2D") -> "PositionCommon_Pos2D":
		pass

	@overload
	def multiply(self, x: float, y: float) -> "PositionCommon_Pos2D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "PositionCommon_Pos2D":
		"""
		Since: 1.6.3 

		Args:
			scale: 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def to3D(self) -> PositionCommon_Pos3D:
		pass

	@overload
	def toVector(self) -> PositionCommon_Vec2D:
		pass

	@overload
	def toVector(self, start_pos: "PositionCommon_Pos2D") -> PositionCommon_Vec2D:
		"""
		Since: 1.6.4 

		Args:
			start_pos: 
		"""
		pass

	@overload
	def toVector(self, start_x: float, start_y: float) -> PositionCommon_Vec2D:
		"""
		Since: 1.6.4 

		Args:
			start_x: 
			start_y: 
		"""
		pass

	@overload
	def toReverseVector(self) -> PositionCommon_Vec2D:
		"""
		Since: 1.6.4 
		"""
		pass

	@overload
	def toReverseVector(self, end_pos: "PositionCommon_Pos2D") -> PositionCommon_Vec2D:
		"""
		Since: 1.6.4 

		Args:
			end_pos: 
		"""
		pass

	@overload
	def toReverseVector(self, end_x: float, end_y: float) -> PositionCommon_Vec2D:
		"""
		Since: 1.6.4 

		Args:
			end_x: 
			end_y: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set

KeyBinding = TypeVar["net.minecraft.client.option.KeyBinding"]
InputUtil_Key = TypeVar["net.minecraft.client.util.InputUtil.Key"]

class FKeyBind_KeyTracker:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def press(self, key: InputUtil_Key) -> None:
		pass

	@overload
	def press(self, bind: KeyBinding) -> None:
		pass

	@overload
	def unpress(self, key: InputUtil_Key) -> None:
		pass

	@overload
	def unpress(self, bind: KeyBinding) -> None:
		pass

	@overload
	def getPressedKeys(self) -> Set[str]:
		pass

	pass





from typing import overload
from typing import TypeVar

CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
ClientWorld = TypeVar["net.minecraft.client.world.ClientWorld"]

class MixinMinecraftClient:
	currentScreen: Screen
	interactionManager: ClientPlayerInteractionManager

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def setScreen(self, screen: Screen) -> None:
		pass

	@overload
	def onJoinWorld(self, world: ClientWorld, info: CallbackInfo) -> None:
		pass

	@overload
	def onOpenScreen(self, screen: Screen, info: CallbackInfo) -> None:
		pass

	@overload
	def afterOpenScreen(self, screen: Screen, info: CallbackInfo) -> None:
		pass

	@overload
	def onDisconnect(self, s: Screen, info: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .Sorting_MacroSortMethod import Sorting_MacroSortMethod

JsonObject = TypeVar["com.google.gson.JsonObject"]
Comparator = TypeVar["java.util.Comparator_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]

class ClientConfigV2:
	sortMethod: Sorting_MacroSortMethod
	disableKeyWhenScreenOpen: bool
	editorTheme: Mapping[str, List[float]]
	editorLinterOverrides: Mapping[str, str]
	editorHistorySize: int
	editorSuggestions: bool
	editorFont: str
	externalEditor: bool
	externalEditorCommand: str

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def languages(self) -> List[str]:
		pass

	@overload
	def getFonts(self) -> List[str]:
		pass

	@overload
	def getThemeData(self) -> Mapping[str, List[float]]:
		pass

	@overload
	def getSortComparator(self) -> Comparator:
		pass

	@overload
	def fromV1(self, v1: JsonObject) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .MethodWrapper import MethodWrapper

Function = TypeVar["java.util.function.Function_xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer_xyz.wagyourtail.jsmacros.core.language.BaseScriptContext____"]
T = TypeVar("T")
U = TypeVar("U")
V = TypeVar("V")

class WrappedScript(Generic[T, U, V], MethodWrapper):
	f: Function
	_async: bool

	@overload
	def __init__(self, f: Function, _async: bool) -> None:
		pass

	@overload
	def accept(self, t: T) -> None:
		pass

	@overload
	def accept(self, t: T, u: U) -> None:
		pass

	@overload
	def apply(self, t: T) -> V:
		pass

	@overload
	def apply(self, t: T, u: U) -> V:
		pass

	@overload
	def test(self, t: T) -> bool:
		pass

	@overload
	def test(self, t: T, u: U) -> bool:
		pass

	@overload
	def run(self) -> None:
		pass

	@overload
	def compare(self, o1: T, o2: T) -> int:
		pass

	@overload
	def get(self) -> V:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

Function = TypeVar["java.util.function.Function_T,java.lang.Boolean_"]
T = TypeVar("T")

class IFilter(Function, Generic[T]):
	"""
	Since: 1.6.5 
	"""

	@overload
	def apply(self, t: T) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from typing import Generic
from .PlayerEntityHelper import PlayerEntityHelper
from .EntityHelper import EntityHelper

T = TypeVar("T")

class ClientPlayerEntityHelper(Generic[T], PlayerEntityHelper):
	"""
	Since: 1.0.3 
	"""

	@overload
	def __init__(self, e: T) -> None:
		pass

	@overload
	def lookAt(self, yaw: float, pitch: float) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.0.3 

		Args:
			pitch: (was yaw prior to 1.2.6) 
			yaw: (was pitch prior to 1.2.6) 
		"""
		pass

	@overload
	def lookAt(self, x: float, y: float, z: float) -> "ClientPlayerEntityHelper":
		"""look at the specified coordinates.\n
		Since: 1.2.8 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def attack(self, entity: EntityHelper) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 

		Args:
			entity: 
		"""
		pass

	@overload
	def attack(self, entity: EntityHelper, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			entity: 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: int) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 

		Args:
			x: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
		"""
		pass

	@overload
	def attack(self, x: int, y: int, z: int, direction: int, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			x: 
			await: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
		"""
		pass

	@overload
	def interactEntity(self, entity: EntityHelper, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			entity: 
			offHand: 
		"""
		pass

	@overload
	def interactEntity(self, entity: EntityHelper, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			entity: 
			offHand: 
		"""
		pass

	@overload
	def interactItem(self, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			offHand: 
		"""
		pass

	@overload
	def interactItem(self, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
			offHand: 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: int, offHand: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0, renamed from 'interact' in 1.6.0 

		Args:
			x: 
			y: 
			z: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 
			offHand: 
		"""
		pass

	@overload
	def interactBlock(self, x: int, y: int, z: int, direction: int, offHand: bool, await_: bool) -> "ClientPlayerEntityHelper":
		pass

	@overload
	def interact(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def interact(self, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def attack(self) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def attack(self, await_: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.0 

		Args:
			await: 
		"""
		pass

	@overload
	def setLongAttack(self, stop: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.3 

		Args:
			stop: 
		"""
		pass

	@overload
	def setLongInteract(self, stop: bool) -> "ClientPlayerEntityHelper":
		"""
		Since: 1.6.3 

		Args:
			stop: 
		"""
		pass

	@overload
	def getItemCooldownsRemainingTicks(self) -> Mapping[str, int]:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getItemCooldownRemainingTicks(self, item: str) -> int:
		"""
		Since: 1.6.5 

		Args:
			item: 
		"""
		pass

	@overload
	def getTicksSinceCooldownsStart(self) -> Mapping[str, int]:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getTicksSinceCooldownStart(self, item: str) -> int:
		"""
		Since: 1.6.5 

		Args:
			item: 
		"""
		pass

	@overload
	def getFoodLevel(self) -> int:
		"""
		Since: 1.1.2 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

NarrationMessageBuilder = TypeVar["net.minecraft.client.gui.screen.narration.NarrationMessageBuilder"]
Consumer = TypeVar["java.util.function.Consumer_xyz.wagyourtail.wagyourgui.elements.Button_"]
PressableWidget = TypeVar["net.minecraft.client.gui.widget.PressableWidget"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class Button(PressableWidget):
	horizCenter: bool
	onPress: Consumer
	hovering: bool
	forceHover: bool

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, color: int, borderColor: int, hilightColor: int, textColor: int, message: Text, onPress: Consumer) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> "Button":
		pass

	@overload
	def cantRenderAllText(self) -> bool:
		pass

	@overload
	def setMessage(self, message: Text) -> None:
		pass

	@overload
	def setColor(self, color: int) -> None:
		pass

	@overload
	def setHilightColor(self, color: int) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float) -> None:
		pass

	@overload
	def onRelease(self, mouseX: float, mouseY: float) -> None:
		pass

	@overload
	def onPress(self) -> None:
		pass

	@overload
	def appendNarrations(self, builder: NarrationMessageBuilder) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping

ClientBossBar = TypeVar["net.minecraft.client.gui.hud.ClientBossBar"]
UUID = TypeVar["java.util.UUID"]

class IBossBarHud:

	@overload
	def jsmacros_GetBossBars(self) -> Mapping[UUID, ClientBossBar]:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IDraw2D import IDraw2D
from .ButtonWidgetHelper import ButtonWidgetHelper
from .TextFieldWidgetHelper import TextFieldWidgetHelper
from .MethodWrapper import MethodWrapper
from .RenderCommon_Rect import RenderCommon_Rect
from .RenderCommon_Item import RenderCommon_Item
from .ItemStackHelper import ItemStackHelper

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class IScreen(IDraw2D):
	"""
	Since: 1.2.7 
	"""

	@overload
	def getScreenClassName(self) -> str:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getTitleText(self) -> str:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getButtonWidgets(self) -> List[ButtonWidgetHelper]:
		"""in '1.3.1' updated to work with all button widgets not just ones added by scripts.\n
		Since: 1.0.5 
		"""
		pass

	@overload
	def getTextFields(self) -> List[TextFieldWidgetHelper]:
		"""in '1.3.1' updated to work with all text fields not just ones added by scripts.\n
		Since: 1.0.5 
		"""
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, text: str, callback: MethodWrapper) -> ButtonWidgetHelper:
		"""
		Since: 1.0.5 

		Args:
			x: 
			width: 
			y: 
			callback: calls your method as a Consumer ButtonWidgetHelper 
			text: 
			height: 
		"""
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, callback: MethodWrapper) -> ButtonWidgetHelper:
		"""
		Since: 1.4.0 

		Args:
			x: 
			width: 
			y: 
			callback: calls your method as a Consumer ButtonWidgetHelper 
			text: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def removeButton(self, btn: ButtonWidgetHelper) -> "IScreen":
		"""
		Since: 1.0.5 

		Args:
			btn: 
		"""
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		"""
		Since: 1.0.5 

		Args:
			onChange: calls your method as a Consumer String 
			x: 
			width: 
			y: 
			message: 
			height: 
		"""
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, zIndex: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		"""
		Since: 1.0.5 

		Args:
			onChange: calls your method as a Consumer String 
			x: 
			width: 
			y: 
			message: 
			height: 
			zIndex: 
		"""
		pass

	@overload
	def removeTextInput(self, inp: TextFieldWidgetHelper) -> "IScreen":
		"""
		Since: 1.0.5 

		Args:
			inp: 
		"""
		pass

	@overload
	def setOnMouseDown(self, onMouseDown: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onMouseDown: calls your method as a BiConsumer PositionCommon_Pos2D , Integer 
		"""
		pass

	@overload
	def setOnMouseDrag(self, onMouseDrag: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onMouseDrag: calls your method as a BiConsumer PositionCommon_Vec2D , Integer 
		"""
		pass

	@overload
	def setOnMouseUp(self, onMouseUp: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onMouseUp: calls your method as a BiConsumer PositionCommon_Pos2D , Integer 
		"""
		pass

	@overload
	def setOnScroll(self, onScroll: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onScroll: calls your method as a BiConsumer PositionCommon_Pos2D , Double 
		"""
		pass

	@overload
	def setOnKeyPressed(self, onKeyPressed: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onKeyPressed: calls your method as a BiConsumer Integer , Integer 
		"""
		pass

	@overload
	def setOnClose(self, onClose: MethodWrapper) -> "IScreen":
		"""
		Since: 1.2.7 

		Args:
			onClose: calls your method as a Consumer IScreen 
		"""
		pass

	@overload
	def close(self) -> None:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> RenderCommon_Rect:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> RenderCommon_Rect:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> RenderCommon_Rect:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def removeRect(self, r: RenderCommon_Rect) -> "IScreen":
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def removeItem(self, i: RenderCommon_Item) -> "IScreen":
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def reloadScreen(self) -> "IScreen":
		"""calls the screen's init function re-loading it.\n
		Since: 1.2.7 
		"""
		pass

	@overload
	def onRenderInternal(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		"""DON'T TOUCH\n
		Since: 1.4.1 
		"""
		pass

	@overload
	def getOnClose(self) -> MethodWrapper:
		pass

	pass





from typing import overload
from typing import TypeVar

Slot = TypeVar["net.minecraft.screen.slot.Slot"]

class IInventory:

	@overload
	def jsmacros_getSlotUnder(self, x: float, y: float) -> Slot:
		pass

	pass


